#include "xttcps.h"

XTtcPs_Config XTtcPs_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"cdns,ttc", /* compatible */
		0xf1e60000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x402b}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1e70000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x402c}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1e80000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x402d}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1e90000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x402e}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1ea0000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x402f}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1eb0000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x4030}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1ec0000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x4031}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"cdns,ttc", /* compatible */
		0xf1ed0000, /* reg */
		0x8f0cba9, /* xlnx,clock-freq */
		{0x4032}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	 {
		 NULL
	}
};